<?php

/**
 * @version    1.3.2
 * @package    com_jphpx
 * @author     Joachim Schmidt <joachim.schmidt@oberquembach.de>
 * @copyright  2021 Joachim Schmidt
 * @license    GNU General Public License Version 2 or later
 */
defined('_JEXEC') or die();

jimport('joomla.application.component.view');

use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Toolbar\ToolbarHelper;

class JphpxViewJphpx_codes extends \Joomla\CMS\MVC\View\HtmlView
{

    protected $items;

    protected $pagination;

    protected $state;

    public function display ($tpl = null)
    {
        $this->state = $this->get('State');
        $this->items = $this->get('Items');
        $this->pagination = $this->get('Pagination');
        $this->filterForm = $this->get('FilterForm');
        $this->activeFilters = $this->get('ActiveFilters');

        // Check for errors.
        if (count($errors = $this->get('Errors')))
        {
            throw new Exception(implode("\n", $errors));
        }

        JphpxHelper::addSubmenu('jphpx_codes');

        $this->addToolbar();

        $this->sidebar = JHtmlSidebar::render();
        parent::display($tpl);
    }

    protected function addToolbar ()
    {
        $state = $this->get('State');
        $canDo = JphpxHelper::getActions();

        ToolbarHelper::title(Text::_('COM_JPHPX_TITLE_JPHPX_CODES'), 'jphpx_codes.png');

        // Check if the form exists before showing the add/edit buttons
        $formPath = JPATH_COMPONENT_ADMINISTRATOR . '/views/jphpx_code';

        if (file_exists($formPath))
        {
            if ($canDo->get('core.create'))
            {
                ToolbarHelper::addNew('jphpx_code.add', 'JTOOLBAR_NEW');

                if (isset($this->items[0]))
                {
                    ToolbarHelper::custom('jphpx_codes.duplicate', 'copy.png', 'copy_f2.png', 'JTOOLBAR_DUPLICATE', true);
                }
            }

            if ($canDo->get('core.edit') && isset($this->items[0]))
            {
                ToolbarHelper::editList('jphpx_code.edit', 'JTOOLBAR_EDIT');
            }
        }

        if ($canDo->get('core.edit.state'))
        {
            if (isset($this->items[0]->state))
            {
                ToolbarHelper::divider();
                ToolbarHelper::custom('jphpx_codes.publish', 'publish.png', 'publish_f2.png', 'JTOOLBAR_PUBLISH', true);
                ToolbarHelper::custom('jphpx_codes.unpublish', 'unpublish.png', 'unpublish_f2.png', 'JTOOLBAR_UNPUBLISH', true);
            }
            elseif (isset($this->items[0]))
            {
                // If this component does not use state then show a direct
                // delete button as we can not trash
                ToolbarHelper::deleteList('', 'jphpx_codes.delete', 'JTOOLBAR_DELETE');
            }

            if (isset($this->items[0]->state))
            {
                ToolbarHelper::divider();
                ToolbarHelper::archiveList('jphpx_codes.archive', 'JTOOLBAR_ARCHIVE');
            }

            if (isset($this->items[0]->checked_out))
            {
                ToolbarHelper::custom('jphpx_codes.checkin', 'checkin.png', 'checkin_f2.png', 'JTOOLBAR_CHECKIN', true);
            }
        }

        // Show trash and delete for components that uses the state field
        if (isset($this->items[0]->state))
        {
            if ($state->get('filter.state') == - 2 && $canDo->get('core.delete'))
            {
                ToolbarHelper::deleteList('', 'jphpx_codes.delete', 'JTOOLBAR_EMPTY_TRASH');
                ToolbarHelper::divider();
            }
            elseif ($canDo->get('core.edit.state'))
            {
                ToolbarHelper::trash('jphpx_codes.trash', 'JTOOLBAR_TRASH');
                ToolbarHelper::divider();
            }
        }

        if ($canDo->get('core.admin'))
        {
            ToolbarHelper::preferences('com_jphpx');
        }

        // Set sidebar action - New in 3.0
        JHtmlSidebar::setAction('index.php?option=com_jphpx&view=jphpx_codes');
    }

    protected function getSortFields ()
    {
        return array(
                'a.id' => Text::_('JGRID_HEADING_ID'),
                'a.title' => Text::_('COM_JPHPX_JPHPX_CODES_TITLE'),
                'a.source' => Text::_('COM_JPHPX_JPHPX_CODES_SOURCE'),
                'a.access' => Text::_('COM_JPHPX_JPHPX_CODES_ACCESS'),
                'a.published' => Text::_('COM_JPHPX_JPHPX_CODES_PUBLISHED')
        );
    }

    public function getState ($state)
    {
        return isset($this->state->{$state}) ? $this->state->{$state} : false;
    }
}
